Белорусский государственный университет информатики и радиоэлектроники

На главную | | Карта сайта | | e-mail |
| en | ru
Схема корпусов | Обратная связь | Форум | Почта | Телефоны БГУИР
Об университете
• История
• Символика и устав БГУИР
• Структура университета
• Почётные доктора БГУИР
• Одно окно
• Система менеджмента университета
• Телефонный справочник БГУИР
• Международное сотрудничество
• Спорт в университете
• Пресс-служба
• СМИ о БГУИР
• Фотогалерея
Образование
• Абитуриентам
• Факультеты
• Кафедры
• Расписание занятий
• Расписание экзаменов
• Стипендии
• Оплата обучения
• Магистратура
• Аспирантура и докторантура
• Научно-методический совет университета
• Советы по защите диссертаций
• Иностранным студентам
• Информационная база УМУ
• Центр языковой подготовки по иностранным языкам
• Повышение квалификации, переподготовка и стажировка
• Взаимодействие с заказчиками кадров
Наука
• Центр трансфера технологий
• Подразделения НИЧ
• Международный Алферовский фонд поддержки образования и науки
• Международный научно-образовательно-инновационный центр инфокоммуникационных технологий и защиты информации
• Научные школы
• Инженерно-образовательный центр ИЗОВАК-БГУИР
• Конференции БГУИР
• Конференции, семинары и курсы
• Конкурсы и гранты
• Экспертные комиссии
• Публикации
Информация
• Система "Расчет"
• Приказы
• Страница юриста
• Компьютерная сеть БГУИР
• Энерго- и ресурсосбережение
• Материалы ВКС
Идеологическая работа
• Структура управления
• Документация
• Нравственный кодекс БГУИР
• Центр культурно-массовой работы
• Молодежные объединения
• Социально-педагогическая и психологическая служба
• Отдел методической и воспитательной работы
• Социальная поддержка
• Ко дню информирования
• Час Фемиды
• Проект "Мой стиль жизни сегодня - Моё здоровье и успех завтра"
Анонс
Декабрь
Пн | Вт | Ср | Чт | Пт | Сб | Вс
1 | 2 | 3 | 4 | 5 | 6 | 7
8 | 9 | 10 В БГУИР будет открыт новый учебный центр Официальное открытие центра состоится 10 декабря в 16.00, на него приглашены представители Министра образования Республики Беларусь, компаний, работающих в области IT-технологий и другие заинтересованные организации. VIII Международная научно-техническая конференция «Средства медицинской электроники и новые медицинские технологии» Приглашаем Вас принять участие в работе конференции «МЕДЭЛЕКТРОНИКА-2014: СРЕДСТВА МЕДИЦИНСКОЙ ЭЛЕКТРОНИКИ И НОВЫЕ МЕДИЦИНСКИЕ ТЕХНОЛОГИИ», которая будет проходить в период с 10 по 11 декабря 2014 года. сайт конференции | 11 Занятия проекта по здоровому образу жизни 11 декабря в 15:30 состоится занятие в рамках профилактического проекта "Мой стиль жизни сегодня - мое здоровье и успех завтра!". Участникам расскажут о профилактике стоматологических заболеваний. Приглашаются старосты 1-го курса ФИТУ ИЭФ, ФКСиС. «Созвездие» приносит радость детям 11 декабря в 17.00 на базе столовой общежития №1 состоится концерт, приуроченный к Международному дню инвалидов | 12 | 13 | 14
15 | 16 Студент года БГУИР 16 декабря в 15.30 в актовом зале университета состоится финал конкурса «Студент года БГУИР». Лучший студент – это не только отличник учебы и интеллектуал, но и творческая личность, спортсмен, активист. Приходите поддержать представителя своего факультета и примите участие в выборе лучшего студента нашего университета! | 17 | 18 | 19 Баскетбол в БГУИР 19 декабря в 18.00 в спортивном зале 2-го учебного корпуса пройдет очередной матч в высшей лиге XXIII Чемпионата Республики Беларусь по баскетболу среди мужских команд. Наша команда «Импульс – БГУИР» примет на своей площадке команду СДЮШОР «Цмокі-Мінск». Вход на матч свободный. Приходите, для команды очень важна поддержка болельщиков! | 20 Заседание Совета университета 20 декабря в 10:00 в зале заседаний университета состоится очередное заседание Совета университета | 21
22 | 23 | 24 | 25 | 26 | 27 | 28
29 | 30 | 31 |  |  |  |
Январь
БГУИР - знания и стиль жизни! 3 учебная неделя
Команда БГУИР выступит в финале мирового первенства по программированию в Марокко Подведены итоги конкурса на лучший дипломный проект Команда турклуба БГУИР - лучшая в технике поисково-спасательных работ Два проекта студентов БГУИР станут участниками республиканского конкурса «100 идей для Беларуси» Проблемы и пути развития высшего технического образования обсудили в БГУИР В Бангладеш откроется международный белорусский университет
Фраза дня: У большинства людей их самый большой успех приходит после того, как они потерпели самый большой крах. К.Тернер
##### Новости 09.12.2014 | Подведены итоги конкурса на лучший дипломный проект
8 декабря на ректорате состоялось вручение дипломов победителям конкурса на лучший дипломный проект. Дипломы победителям конкурса вручил ректор университета М.П. Батура.
09.12.2014 | Команда БГУИР выступит в финале мирового первенства по программированию в Марокко
6-7 декабря в Санкт-Петербурге прошел полуфинал Северо-восточного европейского региона командного чемпионата мира по программированию ACM ICPC. Команда БГУИР представит нашу страну в финале этого престижного первенства по программированию среди студентов.
05.12.2014 | Команда турклуба БГУИР - лучшая в технике поисково-спасательных работ
28-30 ноября команда туристского клуба БГУИР «Альтаир» приняла участие в Кубке Республики Беларусь по туристско-прикладному многоборью в технике поисково-спасательных работ «ПСР-2014» и заняла 1-е место в зачете «Туристские клубы».
04.12.2014 | БГУИР расширяет горизонты международного сотрудничества
С целью расширения сотрудничества в сфере высшего образования с 15 по 23 ноября делегация БГУИР во главе с ректором М.П. Батурой находилась с рабочим визитом в США.
03.12.2014 | В БГУИР прошли занятия по профилактике ОРИ
2 декабря в БГУИР прошло занятие по профилактике острых респираторных инфекций и гриппа в рамках проекта «Мой стиль жизни сегодня - мое здоровье и успех завтра!» Участники проекта встретились с врачом УЗ «25-я городская поликлиника г. Минска» В.М. Морозиком.
03.12.2014 | Дни абитуриента стартовали в БГУИР
29 ноября прошла первая абитуриентская суббота в рамках приемной кампании-2015. Началась она с Дня открытых дверей на военном факультете, а продолжилась - турниром по «Что? Где? Когда?» для школьников.
01.12.2014 | В БГУИР проведены занятия по профилактике зависимостей среди молодежи
27 и 28 ноября в рамках проекта «Мой стиль жизни сегодня - мое здоровье и успех завтра!» в БГУИР проведены занятия по теме «Профилактика зависимостей среди молодежи». Участники проекта встретились с заведующей подростковым отделением УЗ «Минский городской наркологический диспансер» Л.А. Шпаковской и врачом Городского Центра здоровья С.В. Кавриго.
28.11.2014 | «Музыку надо не слушать, а слышать…»
Побывав на концерте живой музыки, прошедшем 27 ноября в общежитии N2, в который раз убеждаешься в правильности слов: музыка - это особый язык, с помощью которого артист должен «достучаться» до слушателя, а задача зрителя - суметь «распробовать» мелодию.
##### Объявления 26.11.2014 | День открытых дверей на военном факультете
29 ноября военный факультет БГУИР проводит День открытых дверей.
19.11.2014 | Студенческий городок приглашает
Приглашаем студентов и сотрудников университета на творческое мероприятие проекта "Великолепная 4-ка", которое пройдет 20 ноября в 18:00 в столовой N225 общежития N2 по ул. Л.Беды, 4.
19.11.2014 | Итоги конкурса перевода «Я - студэнт беларускай ВНУ»
С 22 сентября по 17 ноября в БГУИР проводился конкурс перевода «Я - студэнт беларускай ВНУ», посвящённый Международному дню студентов. Конкурсная работа представляла собой литературный перевод стихотворения М.В. Исаковского «Формула любви» с русского языка на белорусский.
19.11.2014 | Вакцинация от гриппа
Приглашаем сотрудников, преподавателей и студентов на вакцинацию от гриппа в кабинет медицинского пункта N 905 5-корпус (ул.Платонова,39) Вакцина "Инфлювак" (Нидерланды), количество вакцины ограничено. Телефон для справок 293-80-82
18.11.2014 | Открытый турнир по ЧГК для школьников
Факультет компьютерных систем и сетей БГУИР при поддержке профкома студентов БГУИР приглашает команды принять участие в I Открытом турнире по "Что? Где? Когда?" для школьников.
Архив
Юридический адрес: Республика Беларусь, 220013 г. Минск, ул. П.Бровки 6 Телефоны: т/факс +375 17 202 10 33 приемная ректора +375 17 293 88 15 приемная комиссия E-mail: kanc@bsuir.by
| ##### Сайты
###### Подразделения БГУИР :: Электронный ректорат :: ИИТ БГУИР :: Библиотека :: Профком работников БГУИР :: Студенческий профком :: Студгородок :: Газета "Импульс" :: Мониторинг СППС :: Опрос "Первокурсник"
###### Конференции :: МНМК-2014 "Высшее техническое образование: проблемы и пути развития" :: Медэлектроника-2014 :: OSTIS-2015
###### Объединения и организации :: Виртуальный музей :: Учебно-методическое объединение
###### Тематические сайты :: BIT-Cup 2014 :: Олимпиады по программированию БГУИР :: VHDL - обучающий портал :: Антивирусный центр :: SOFT-архив :: ЭУМКД :: Журнал "Доклады БГУИР"
Погода в Минске
Gismeteo Подробнее
разработка: © Центр Информатизации и Инновационных Разработок, 2002-2014